import axios from 'axios';
import { findIndex, includes, zipWith } from 'ramda';

export async function validateInput(input, actualString) {
    const isValidLength = checkInputLength(input, 5);
    if (!isValidLength) {
        return { "result": null, "error": "Not enough characters" };
    }

    const isInputDefined = await checkInputDefined(input);
    if (isInputDefined["res"] === false) {
        return { "result": null, "error": "Word is not defined" };
    } else if (isInputDefined["error"]) {
        return { "result": null, "error": "Validation error: " + isInputDefined["error"] };
    }

    let actual = actualString.split("");

    const checkCorrect = (i, a) => {
        const status = (i === a) ? "correct" : "incorrect";
        return status;
    }
    const firstEvaluation = zipWith(checkCorrect, input, actual);
  
    const lastEvaluation = firstEvaluation.map((e, idx) => {
        const word = input[idx];
        if (e === "correct") {
            actual[idx] = '';
        }
        else if (e === "incorrect" && includes(word, actual)) {
            const actualIdx = findIndex((i) => word === i)(actual);
            actual[actualIdx] = '';
            return "misplaced";
        } 
        return e;
    });
    
    return { "result": lastEvaluation, "error": null };
}

function checkInputLength(input, length) {
    const isValid = (input.length === length) ? true : false;
    return isValid;
}

async function checkInputDefined(input) {
    const response = await axios({
        method: 'get',
        url: 'https://katla-backend2-vzlajmqxxq-et.a.run.app/check/' + input.join(""),
    });
    if (response.statusText === "OK") {
        return { "res": response.data, "error": null };
    } else {
        return { "res": null, "error": response.statusText };
    }
}
